/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxJwsHandlerChainVisitor.java 3804 2008-08-07 13:57:58Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import org.ow2.util.ee.metadata.common.api.interfaces.IHandlerChain;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.ee.metadata.common.impl.struct.JwsHandlerChain;

/**
 * This class manages the handling of &#64;{@link javax.jws.HandlerChain}
 * annotation.
 * @param <T> An implementation of IHandlerChain interface.
 * @author Guillaume Sauthier
 */
public class JavaxJwsHandlerChainVisitor<T extends IHandlerChain> extends AbsAnnotationVisitor<T> {

    /**
     * Supported type of the annotation visitor.
     */
    public static final String TYPE = "Ljavax/jws/HandlerChain;";

    /**
     * 'file' attribute name.
     */
    private static final String ATTR_FILE = "file";

    /**
     * Parsed HandlerChain metadata.
     */
    private IJwsHandlerChain jwsHandlerChain = null;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxJwsHandlerChainVisitor(final T annotationMetadata) {
        super(annotationMetadata);
        jwsHandlerChain = new JwsHandlerChain();
    }

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.util.scan.api.IType}.
     */
    @Override
    public void visit(final String name, final Object value) {
        if (name.equals(ATTR_FILE)) {
            jwsHandlerChain.setFile((String) value);
        }
    }

    /**
     * Visits the end of the annotation.
     */
    public void visitEnd() {
        getAnnotationMetadata().setJwsHandlerChain(jwsHandlerChain);
    }

    /**
     * @return type of the annotation (its description).
     */
    public String getType() {
        return TYPE;
    }
}
